pub struct SqliteStorage { /* private fields */ }
A Storage implementation based on an SQLite database.

Implementations

Opens a new SQLite database in the given path.

If the database does not already exist it will be created.

use datacake_sqlite::SqliteStorage;

let storage = SqliteStorage::open("./data.db").await.expect("Create database");

Opens a new SQLite database in memory.

use datacake_sqlite::SqliteStorage;

let storage = SqliteStorage::open_in_memory().await.expect("Create database");

Creates a new SqliteStorage instances from an existing storage handle.

Creates a copy of the storage handle to be used in other sections of code which do not need to be distributed.

WARNING: Any changes made to this will not be reflected in the cluster, it is primarily only provided for ease of reading.

The table state_entries is already created and reserved.