Struct datacake_sqlite::StorageHandle
source · pub struct StorageHandle { /* private fields */ }Expand description
A asynchronous wrapper around a SQLite database.
These operations will be ran in a background thread preventing any IO operations from blocking the async context.
Implementations
sourceimpl StorageHandle
impl StorageHandle
sourcepub async fn open(path: impl AsRef<Path>) -> Result<Self>
pub async fn open(path: impl AsRef<Path>) -> Result<Self>
Connects to the SQLite database.
This spawns 1 background threads with actions being executed within that thread.
This approach reduces the affect of writes blocking reads and vice-versa.
sourcepub async fn open_in_memory() -> Result<Self>
pub async fn open_in_memory() -> Result<Self>
Connects to a new in-memory SQLite database.
sourcepub async fn execute<P>(&self, sql: impl AsRef<str>, params: P) -> Result<usize>where
P: Params + Clone + Send + 'static,
pub async fn execute<P>(&self, sql: impl AsRef<str>, params: P) -> Result<usize>where P: Params + Clone + Send + 'static,
Execute a SQL statement with some provided parameters.
sourcepub async fn execute_many<P>(
&self,
sql: impl AsRef<str>,
param_set: Vec<P>
) -> Result<usize>where
P: Params + Clone + Send + 'static,
pub async fn execute_many<P>( &self, sql: impl AsRef<str>, param_set: Vec<P> ) -> Result<usize>where P: Params + Clone + Send + 'static,
Execute a SQL statement several times with some provided parameters.
The statement is executed within the same transaction.
sourcepub async fn fetch_one<P, T>(
&self,
sql: impl AsRef<str>,
params: P
) -> Result<Option<T>>where
P: Params + Send + 'static,
T: FromRow + Send + 'static,
pub async fn fetch_one<P, T>( &self, sql: impl AsRef<str>, params: P ) -> Result<Option<T>>where P: Params + Send + 'static, T: FromRow + Send + 'static,
Fetch a single row from a given SQL statement with some provided parameters.