Trait datacake_sqlite::FromRow
source · pub trait FromRow: Sized {
// Required method
fn from_row(row: &Row<'_>) -> Result<Self>;
}Expand description
A helper trait for converting between a Row reference and the given type.
This is required due to the nature of rows being tied to the database connection which cannot be shared outside of the thread the actor runs in.