pub trait FromRow: Sized {
    fn from_row(row: &Row<'_>) -> Result<Self>;
}
A helper trait for converting between a Row reference and the given type.

This is required due to the nature of rows being tied to the database connection which cannot be shared outside of the thread the actor runs in.

Required Methods

Implementations on Foreign Types

Implementors